@@ -7,13 +7,11 @@ no warnings;
 use subs qw();
 use vars qw($VERSION);
 
-$VERSION = '1.043_02';
-
-=encoding utf8
+$VERSION = '1.01';
 
 =head1 NAME
 
-Module::Extract::Use - Pull out the modules a module explicitly uses
+Module::Extract::Use - Pull out the modules a module uses
 
 =head1 SYNOPSIS
 
@@ -24,8 +22,8 @@ Module::Extract::Use - Pull out the modules a module explicitly uses
 	my @modules = $extor->get_modules( $file );
 	if( $extor->error ) { ... }
 
-	my $details = $extor->get_modules_with_details( $file );
-	foreach my $detail ( @$details ) {
+	my @details = $extor->get_modules_with_details( $file );
+	foreach my $detail ( @details ) {
 		printf "%s %s imports %s\n",
 			$detail->module, $detail->version,
 			join ' ', @{ $detail->imports }
@@ -35,9 +33,7 @@ Module::Extract::Use - Pull out the modules a module explicitly uses
 
 Extract the names of the modules used in a file using a static
 analysis. Since this module does not run code, it cannot find dynamic
-uses of modules, such as C<eval "require $class">. It only reports modules
-that the file loads directly or are in the import lists for L<parent>
-or L<base>.
+uses of modules, such as C<eval "require $class">.
 
 =cut
 
@@ -72,12 +68,12 @@ sub init {
 
 =item get_modules( FILE )
 
-Returns a list of namespaces explicity use-d in FILE. Returns undef if
-the file does not exist or if it can't parse the file.
+Returns a list of namespaces explicity use-d in FILE. Returns undef if the
+file does not exist or if it can't parse the file.
 
-Each used namespace is only in the list even if it is used multiple
-times in the file. The order of the list does not correspond to
-anything so don't use the order to infer anything.
+Each used namespace is only in the list even if it is used multiple times
+in the file. The order of the list does not correspond to anything so don't
+use the order to infer anything.
 
 =cut
 
@@ -89,9 +85,9 @@ sub get_modules {
 	my $details = $self->get_modules_with_details( $file );
 	return unless defined $details;
 
-	my @modules = map { $_->module } @$details;
-
-	@modules;
+	my @modules =
+		map { $_->{module} }
+		@$details;
 	}
 
 =item get_modules_with_details( FILE )
@@ -102,8 +98,6 @@ explicitly use-d in FILE. Each reference has keys for:
 	namespace - the namespace, always defined
 	version   - defined if a module version was specified
 	imports   - an array reference to the import list
-	pragma    - true if the module thinks this namespace is a pragma
-	direct    - false if the module name came from parent or base
 
 Each used namespace is only in the list even if it is used multiple
 times in the file. The order of the list does not correspond to
@@ -117,7 +111,7 @@ sub get_modules_with_details {
 	$self->_clear_error;
 
 	my $modules = $self->_get_ppi_for_file( $file );
-	return [] unless defined $modules;
+	return unless defined $modules;
 
 	$modules;
 	}
@@ -138,31 +132,6 @@ sub _get_ppi_for_file {
 		return;
 		}
 
-	# this handles the
-	#   use Foo;
-	#   use Bar;
-	my $regular_modules = $self->_regular_load( $Document );
-
-	# this handles
-	#   use parent qw(...)
-	my $isa_modules      = $self->_isa_load( $regular_modules );
-
-	# this handles
-	#   my $rc = require Foo;
-	my $expression_loads = $self->_expression_load( $Document );
-
-	my @modules = map { @$_ }
-		$regular_modules,
-		$isa_modules,
-		$expression_loads
-		;
-
-	return \@modules;
-	}
-
-sub _regular_load {
-	my( $self, $Document ) = @_;
-
 	my $modules = $Document->find(
 		sub {
 			$_[1]->isa( 'PPI::Statement::Include' )  &&
@@ -170,86 +139,23 @@ sub _regular_load {
 			}
 		);
 
-	return [] unless $modules;
+	return unless $modules;
 
 	my %Seen;
 	my @modules =
 		grep { ! $Seen{ $_->{module} }++ && $_->{module} }
 		map  {
-			my $hash = bless {
-				direct  => 1,
-				content => $_->content,
+			my $hash = {
 				pragma  => $_->pragma,
 				module  => $_->module,
 				imports => [ $self->_list_contents( $_->arguments ) ],
 				version => eval{ $_->module_version->literal || ( undef ) },
-				}, 'Module::Extract::Use::Item';
+				};
 			} @$modules;
 
-	\@modules;
+	return \@modules;
 	}
 
-sub _isa_load {
-	my( $self, $modules ) = @_;
-	my @isa_modules =
-		map {
-			my $m = $_;
-			map {
-				bless {
-					content => $m->content,
-					pragma  => undef,
-					direct  => 0,
-					module  => $_,
-					imports => [],
-					version => undef,
-					}, 'Module::Extract::Use::Item';
-				} @{ $m->imports };
-			}
-		grep { $_->module eq 'parent' or $_->module eq 'base' }
-		@$modules;
-
-	\@isa_modules;
-	}
-
-sub _expression_load {
-	my( $self, $Document ) = @_;
-
-	my $in_statements = $Document->find(
-		sub {
-			$_[1]->isa( 'PPI::Token::Word' ) &&
-			$_[1]->content eq 'require'
-			}
-		);
-
-	return [] unless $in_statements;
-
-	my @modules =
-		map {
-			bless {
-				content => $_->parent->content,
-				pragma  => undef,
-				direct  => 1,
-				module  => $_->snext_sibling->content,
-				imports => [],
-				version => undef,
-				}, 'Module::Extract::Use::Item';
-			}
-		@$in_statements;
-
-	\@modules;
-	}
-
-BEGIN {
-package Module::Extract::Use::Item;
-
-sub direct  { $_[0]->{direct}  }
-sub content { $_[0]->{content} }
-sub pragma  { $_[0]->{pragma}  }
-sub module  { $_[0]->{module}  }
-sub imports { $_[0]->{imports} }
-sub version { $_[0]->{version} }
-}
-
 sub _list_contents {
 	my( $self, $node ) = @_;
 
@@ -287,15 +193,19 @@ sub error        { $_[0]->{error} }
 
 =head1 TO DO
 
+=over 4
+
+=item * Make it recursive, so it scans the source for any module that it finds.
+
+=back
+
 =head1 SEE ALSO
 
-L<Module::ScanDeps>, L<Module::Extract>
+L<Module::ScanDeps>
 
 =head1 SOURCE AVAILABILITY
 
-The source code is in Github:
-
-	https://github.com/briandfoy/module-extract-use
+The source code is in Github: git://github.com/briandfoy/module-extract-use.git
 
 =head1 AUTHOR
 
@@ -303,9 +213,9 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2008-2020, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright (c) 2008-2011, brian d foy, All Rights Reserved.
 
-This project is under the Artistic License 2.0.
+You may redistribute this under the same terms as Perl itself.
 
 =cut
 
